set more 1
capture log close

/*
File:	create_imf_lmi_3.do
Date:	Jul 31, 2003
Desc:	creates Stata version of IMF Labor Market Institutions database
*/

/* set directories 
see master_imf_lmi.do
*/

/* Sort data sets (first time only)

local i=1
while `i'<=3 {
use "$mydoc$data\imf_sheet`i'.dta", clear
sort country year
save "$mydoc$data\imf_sheet`i'.dta", replace
local i=`i'+1
}

*/

/* Merge data sets (first time only) 

use "$mydoc$data\imf_sheet1.dta", clear
merge country year using "$mydoc$data\imf_sheet2.dta"
tab _merge /* check _merge */
pause on
/* "Type 'end' or 'q' to continue" */
pause
drop _merge
sort country year
merge country year using "$mydoc$data\imf_sheet3.dta"
tab _merge  /* check _merge */
/* "Type 'end' or 'q' to continue" */
pause
drop _merge
drop if year==.
drop if country==""
sort country year
compress
lab data "IMF, LMI, raw data"
save "$mydoc$data\imf_lmi_raw.dta", replace

*/

use "$mydoc$data\imf_lmi_raw.dta", clear

/* Label data */

lab var country "Country"
*
lab var year "Year"
*
lab var unr "Unemployment rate"
notes unr: Percent
*
lab var ep "Employment protection"
notes ep: Index, 0-2
*
rename un ud
lab var ud "Union density"
notes ud: Share
*
lab var bc1 "Bargaining coordination, 1"
notes bc1: Index, 1-3
*
lab var bc2 "Bargaining coordination, 2"
notes bc2: Index, 1-3
*
lab var brr "Replacement rate"
notes brr: Share
*
lab var bd "Benefit duration"
notes bd: Source: Nickell et al (2001)
*
lab var tw "Tax wedge"
notes tw: Sum of the employment tax rate, direct tax rate, and indirect /*
*/ tax rates
notes tw: One unit equals 100%
*
lab var ho "Home ownership"
notes ho: Share
*
lab var cbi "Central bank independence"
notes cbi: Index, 0-1
*
lab var esi "Eijfinger-Schaling index"
notes esi: Central bank independence
notes esi: Index, 1-5
*
lab var rir "Real interest rate"
notes rir: Nominal  returns  on long-term government bond, minus the /* 
*/ actual inflation rate in the following year
notes rir: One unit equals 100%
*
lab var prodw "Productivity per worker"
notes prodw: Productivity per worker, source & units TK
*
lab var prod1 "Productivity"
notes prod1: OECD productivity measure, units TK
*
lab var infl "Inflation (CPI)"
notes infl: One unit equals 100%
*
lab var open "Trade openness"
notes open: TK
*
lab var pim "Import prices"
notes pim: Index, 1995=100
*
lab var pex "Export prices"
notes pex: Index, 1995=100
*
lab var tot "Terms of trade"
notes tot: Ratio of export prices (pex) to import prices (pim) 
notes tot: 1995=1.00
*
lab var tots "Terms of trade shock"
notes tots: Documentation says this is first log difference of terms of /*
*/ trade (tot), but tots~=ln(tot_t)-ln(tot_t-1)
*
lab var gap "Output gap"
notes gap: OECD measure of output gap, percent of GDP
*
lab var gempl "Growth public sector employment"
notes gempl: One unit equals 100%
*
lab var oil "Oil price change"
notes oil: Annual price change in dollar spot price index
notes oil: Identical for all countries in a given year
notes oil: One unit equals 100%
notes oil: Source: IFS
*
lab var usd "USD exchange rate change"
notes usd: Annual change in US dollar exchange rate
notes usd: One unit equals 100%
*
lab var dpoil "Domestic oil price change"
notes dpoil: Annual domestic price change for oil
notes dpoil: Equals annual price change in dollar spot price index (oil) /*
*/ minus annual change in the US dollar exchange rate (usd)
notes dpoil: One unit equals 100%
*
lab var sharp "Share price, nominal change"
notes sharp: Nominal annual change in share prices
notes sharp: One unit equals 100%
notes sharp: Source: IFS
*
lab var rsharp "Share price, real change"
notes rsharp: Real annual change in share prices
notes rsharp: One unit equals 100%
notes rsharp: Source: IFS

/* Add new, updated, and alternative versions of variables */

	/* Three-letter country abbreviation */
gen str3 cty="AUS" if country=="Australia"
replace cty="AUT" if country=="Austria"
replace cty="BEL" if country=="Belgium"
replace cty="CAN" if country=="Canada"
replace cty="DEN" if country=="Denmark"
replace cty="FIN" if country=="Finland"
replace cty="FRA" if country=="France"
replace cty="GER" if country=="Germany"
replace cty="IRE" if country=="Ireland"
replace cty="ITA" if country=="Italy"
replace cty="JAP" if country=="Japan"
replace cty="NEL" if country=="Netherlands"
replace cty="NEW" if country=="New Zealand"
replace cty="NOR" if country=="Norway"
replace cty="POR" if country=="Portugal"
replace cty="SPA" if country=="Spain"
replace cty="SWE" if country=="Sweden"
replace cty="SWZ" if country=="Switzerland"
replace cty="UK_" if country=="United Kingdom"
replace cty="USA" if country=="United States"

	/* Benefit replacement ratio, benefit duration */
merge country year using "$mydoc$data\brr_dur.dta"
drop if year==.
drop _merge

lab var brr_alt "Replacement rate, alt"
notes brr_alt: OECD data, provided by Andrew Glyn
notes brr_alt: 1961 data used for 1960, too

lab var bd_alt "Benefit duration, alt"
notes bd_alt: OECD data, provided by Andrew Glyn
notes bd_alt: 1961 data used for 1960, too

	/* Trade union density */
sort country year
merge country year using "$mydoc$data\tu_density.dta"
drop _merge

rename un_alt ud_alt
replace ud_alt=ud_alt/100 /* convert from percent to share */
replace ud_alt=ud if 1960<=year & year<=1994 /* ud_alt updates 1995-99 only */
/* where no updates are available, use existing values for un */
replace ud_alt=ud if 1995<=year & /*
*/ (country=="Belgium" | country=="Canada" | country=="France" | /*
*/  country=="Portugal" | country=="Switzerland")

lab var ud_alt "Union density, alt"
notes ud_alt: 1995-1999 values provided by Andrew Glyn
notes ud_alt: 1995-1999 values for the US from EPI (www.epinet.org)
notes ud_alt: 1960-1994 values identical to ud
notes ud_alt: 1995-1999 values for BEL, CAN, FRA, POR, SWZ identical to ud

	/* Labor force (thousands) */
sort country year
merge country year using "$mydoc$data\oecd_lfs.dta"
drop _merge

lab var lf_all "Labor force"
notes lf_all: In thousands
notes lf_all: Men and women
notes lf_all: OECD, Labor Market Statistics Data
notes lf_all: http://www1.oecd.org/scripts/cde/viewbase.asp?DBNAME=lfs_data

	/* Tax wedge */
sort country year
merge country year using "$mydoc$data\taxesstacked.dta"
drop _merge

gen tw_alt1=g1/100 /* convert from percent to share */
lab var tw_alt1 "Tax wedge, alt1"
notes tw_alt1: Updated version of Nickell et al tax wedge
notes tw_alt1: BGHS variable tax_g1

gen tw_alt2=g2/100  /* convert from percent to share */
lab var tw_alt2 "Tax wedge, alt2"
notes tw_alt2: Updated version of Nickell et al tax wedge
notes tw_alt2: BGHS variable tax_g2

		/* correct IMF data for Spain 1960-63 */
gen tw_cor=tw
replace tw_cor=. if country=="Spain" & (1960<=year & year<=1963)
lab var tw_cor "Tax wedge, corrected"
notes tw_cor: Original tw series, corrected for data error Spain, 1960-63

	/* Active Labor Market Policies (new) */
sort cty year
merge cty year using "$mydoc$almp\oecd_almp.dta"
* tab _merge
drop _merge
lab var almp "ALMP/GDP"
notes almp: ALMP expenditures as a percent of GDP
notes almp: Not available before 1985
notes almp: OECD data, provided by Andrew Glyn

	/* Employment-to-population rate (new) */
		/* Nickell et al data for 1960-1995 */
sort country year
merge country year using "$mydoc$data\nickell_epop.dta"
drop _merge
		/* OECD Employment Outlook, June 2001, July 2002, Table B */
sort country year 
merge country year using "$mydoc$data\oecd_epop_unem.dta", update
drop _merge

	/* Standardized unemployment rate (update) */
		/* sur 1999-2000 from OECD Employment Outlook, July 2002; 
		   use IMF numbers for 1960-1998
		*/
replace sur=unr if 1960<=year & year<=1998 

/* Format data */

format epop unr sur prod1 pim pex gap %5.1f
format ep bc1 bc2 bd bd_alt esi open %5.2f
format ud ud_alt brr brr_alt ho tw tw_alt1 tw_alt2 tw_cor gempl cbi rir infl tot /*
*/ tots oil usd dpoil sharp rsharp prodw %5.3f
format lf_all %9.0f

/* Three-letter country abbreviation */
lab var cty "Country"

/* Save IMF LMI data set */

drop if country==""
sort country year
drop if country=="Sweden" & year[_n]==year[_n-1]

#delimit ;
keep country cty year epop lf_all unr sur ep ud ud_alt bc1 bc2 brr brr_alt 
bd bd_alt tw tw_cor tw_alt1 tw_alt2 almp ho cbi esi rir prodw prod1 infl
open pim pex tot tots gap gempl oil usd dpoil sharp rsharp;
order country cty year epop lf_all unr sur ep ud ud_alt bc1 bc2 brr brr_alt 
bd bd_alt tw tw_cor tw_alt1 tw_alt2 almp ho cbi esi rir prodw prod1 infl
open pim pex tot tots gap gempl oil usd dpoil sharp rsharp;
#delimit cr

lab data "IMF LMI Data"
sort country year
save "$mydoc$data\imf_lmi_ver6.dta", replace old
save "$mydoc$data\imf_lmi.dta", replace

/* Create codebook */

capture program drop cb1
program define cb1
qui log using "$mydoc$data\codebook_imf_lmi.log", replace
di
di "Codebook for IMF Labor Market Institutions Data Base"
di 
di "Data set used for IMF, World Economic Outlook,April 2003,"
di "Chapter IV: Unemployment and Labor Market Institutions:"
di "Why Reforms Pay Off"
di
di _col(1) "Date: $S_DATE" _col(20) "Time: $S_TIME"
di
di 
di "SUMMARY"
di
d
di
di
di
di "DETAILS"
di
codebook, notes tabulate(42) /* tab(42) displays all countries and year */
qui log close
end

cb1 /* create codebook */


